- Inheritance
-
- Object
- PlatformInterface
- XYUmengPlatform
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addLinkListener({required XYLinkInstallFunction onInstall, required XYLinkWakeupFunction onWakeup, required XYLinkError onError})
→ void
-
UMLink
-
getInstallParams({bool enablePasteboard = true})
→ void
-
-
getIsInit()
→ Future<bool>
-
-
getOaid()
→ Future<String?>
-
-
getPlatformVersion()
→ Future<String?>
-
-
init({required String androidAppKey, required String iosAppKey, String? channel, String? androidMessageSecret})
→ Future<void>
-
UMCommon
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onEvent(String eventId, {String? label, Map<String, String>? attributes})
→ void
-
-
onKillProcess()
→ Future<void>
-
-
onPageEnd(String pageName)
→ void
-
-
onPageStart(String pageName)
→ void
-
-
setAutoPageEnabled(bool enabled)
→ Future<void>
-
-
setEncryptEnabled(bool enabled)
→ Future<void>
-
-
setLogEnabled(bool enabled)
→ Future<void>
-
-
setUserProfile(String? mobile, String? email, {String? key, String? value})
→ void
-
-
signIn(String userId, {String? provider})
→ void
-
-
signOff()
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited